@@ -11,6 +11,30 @@ pub struct Bodies {
     bodies: Vec<Body>,
 }
 
+impl Bodies {
+    /// Get the first `Body` in this list of `Bodies`
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use mit_commit::{Bodies, Body, Subject};
+    ///
+    /// let bodies: Vec<Body> = Vec::default();
+    /// assert_eq!(None, Bodies::from(bodies).first());
+    ///
+    /// let bodies: Vec<Body> = vec![
+    ///     Body::from("First"),
+    ///     Body::from("Second"),
+    ///     Body::from("Third"),
+    /// ];
+    /// assert_eq!(Some(Body::from("First")), Bodies::from(bodies).first());
+    /// ```
+    #[must_use]
+    pub fn first(&self) -> Option<Body> {
+        self.bodies.first().cloned()
+    }
+}
+
 impl Display for Bodies {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         write!(f, "{}", String::from(self.clone()))
@@ -109,6 +133,15 @@ mod tests {
             ))
         )
     }
+    #[test]
+    fn get_first() {
+        let bodies = Bodies::from(vec![
+            Body::from("Message Body"),
+            Body::from("Another Message Body"),
+        ]);
+
+        assert_eq!(bodies.first(), Some(Body::from("Message Body")))
+    }
 
     #[test]
     fn it_can_parse_itself_from_an_ast() {
