@@ -3,7 +3,7 @@ use std::convert::TryFrom;
 use thiserror::Error;
 
 /// A `Trailer` you might see a in a `CommitMessage`, for example 'Co-authored-by: Billie Thompson <billie@example.com>'
-#[derive(Debug, PartialEq, Clone)]
+#[derive(Debug, PartialEq, Clone, Eq, Hash)]
 pub struct Trailer {
     key: String,
     value: String,
